<?php
/*
 +-------------------------------------------------------------------------+
 | Copyright (C) 2008 Susanin                                          |
 |                                                                         |
 | This program is free software; you can redistribute it and/or           |
 | modify it under the terms of the GNU General Public License             |
 | as published by the Free Software Foundation; either version 2          |
 | of the License, or (at your option) any later version.                  |
 |                                                                         |
 | This program is distributed in the hope that it will be useful,         |
 | but WITHOUT ANY WARRANTY; without even the implied warranty of          |
 | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           |
 | GNU General Public License for more details.                            |
 +-------------------------------------------------------------------------+
*/

/*******************************************************************************

    Author ......... Susanin (gthe in forum.cacti.net)
    Program ........ SNMPTT viewer for cacti
    Version ........ 0.0.08b

*******************************************************************************/

define("SNMP_METHOD_PHP_SET", 1);
define("SNMP_METHOD_BINARY_SET", 2);

include_once($config["base_path"] . "/lib/poller.php");

/**
 * The RegEx validation class .
 *
 * Usage:
 * if (!RegEx::isValid($expression)) {
 *    echo 'Your regular expression is invalid because: ' . RegEx::error();
 * }
 */
class RegEx {
    /**
     * Validates a regular expression. Returns TRUE
     * if the expression is valid, FALSE if not. If
     * the expression is not valid, the reason why
     * can be fetched from RegEx::error().
     *
     * @access public
     * @static
     * @param string $regex Regular Expression
     * @return bool
     */
    function isValid($regex)
    {
        RegEx::error(FALSE);
       
        set_error_handler(array('RegEx', 'errorHandler'));
        preg_match($regex, '');
        restore_error_handler();
       
        return (RegEx::error() === FALSE) ? TRUE : FALSE;
    }
   
    /**
     * Error handler for RegEx. Used internally by RegEx::validate()
     *
     * @access package
     * @static
     * @param int $code Error Code
     * @param string $message Error Message
     */
    function errorHandler($code, $message)
    {
        // Cuts off the 'preg_match(): ' part of the error message.
        $error = substr($message, 14);
       
        // Sets the error flag with the message.
        RegEx::error($error);
    }
   
    /**
     * Holds the error from the last validation check.
     *
     * The first parameter is used internally and should
     * not be used by the developer.
     *
     * @access public
     * @static
     * @param FALSE|string $value value to set for $flag
     * @return FALSE|string
     */
    function error($value = NULL)
    {
        static $flag = FALSE;
        if (!is_null($value))
        {
            $flag = $value;
        }
        return $flag;
    }
}

/*	valid_snmp_device - This function validates that the device is reachable via snmp.
  It first attempts	to utilize the default snmp readstring.  If it's not valid, it
  attempts to find the correct read string and then updates several system
  information variable. it returns the status	of the host (up=true, down=false)
*/
/* we must use an apostrophe to escape community names under Unix in case the user uses
characters that the shell might interpret. the ucd-snmp binaries on Windows flip out when
you do this, but are perfectly happy with a quotation mark. */
if ($config["cacti_server_os"] == "unix") {
	define("SNMP_SET_ESCAPE_CHARACTER", "'");
}else{
	define("SNMP_SET_ESCAPE_CHARACTER", "\"");
}

if (phpversion () < "5"){ // define PHP5 functions if server uses PHP4

function str_split($text, $split = 1)
{
if (!is_string($text)) return false;
if (!is_numeric($split) && $split < 1) return false;
$len = strlen($text);
$array = array();
$s = 0;
$e=$split;
while ($s <$len)
    {
        $e=($e <$len)?$e:$len;
        $array[] = substr($text, $s,$e);
        $s = $s+$e;
    }
return $array;
}
}
if (! function_exists("array_fill_keys")) {
	function array_fill_keys($array, $values) {
	    if(is_array($array)) {
	        foreach($array as $key => $value) {
	            $arraydisplay[$array[$key]] = $values;
	        }
	    }
	    return $arraydisplay;
	} 
}
/* register this functions scanning functions */
function snmptt_debug($message) {
	global $snmptt_debug;

	if ($snmptt_debug) {
		print("snmptt_DEBUG (" . date("H:i:s") . "): [" . $message . "]\n<br>");
	}
	

	if (substr_count($message, "ERROR:")) {
		cacti_log($message, false, "SNMPTT");
	}
	cacti_log($message, false, "SNMPTT");
}

function snmptt_check_changed($request, $session) {
    if ((isset($_REQUEST[$request])) && (isset($_SESSION[$session]))) {
        if ($_REQUEST[$request] != $_SESSION[$session]) {
            return 1;
        }
    }
}




function run_poller_snmptt($device_id) {
global  $config;

$exit_snmptt = FALSE;
$current=0;

    $command_string = read_config_option("path_php_binary"); 
    $extra_args = " -q " . $config["base_path"] . "/plugins/snmptt/poller_snmptt.php -id=" . $device_id ;
    exec_background($command_string, $extra_args);
    sleep(2);
    /* wait for last process to exit */
        $processes_running = db_fetch_cell("SELECT count(*) FROM snmptt_processes WHERE device_id = '" . $device_id . "'");
        while (($processes_running > 0) && (!$exit_snmptt)) {
            $processes_running = db_fetch_cell("SELECT count(*) FROM snmptt_processes WHERE device_id = '" . $device_id . "'");

            /* wait the correct number of seconds for proccesses prior to
               attempting to update records */
            sleep(2);

            /* take time to check for an exit condition */
            list($micro,$seconds) = split(" ", microtime());
            $current = $seconds + $micro;

            /* exit if we've run too long */
 //           if (($current - $start) > $max_run_duration) {
 //              $exit_snmptt = TRUE;
 //               cacti_log("ERROR: IpMacPort Blinding timed out during main script processing.\n");
 //               break;
 //           }

            snmptt_debug("Waiting on " . $processes_running . " to complete prior to exiting.");
            //Print("Waiting on " . $processes_running . " to complete prior to exiting.");
        }
        
}

function snmptt_draw_actions_dropdown($actions_array, $actions_type) {
    global $config;
    ?>
    <table align='center' width='98%'>
        <tr>
            <td width='1' valign='top'>
                <img src='<?php echo $config['url_path']; ?>images/arrow.gif' alt='' align='absmiddle '>&nbsp;
            </td>
            <td align='right'>
                Choose an action:
                <?php form_dropdown("drp_action",$actions_array,"","","1","","");?>
            </td>
            <td width='1' align='right'>
                <input type='image' src='<?php echo $config['url_path']; ?>images/button_go.gif' alt='Go'>
            </td>
        </tr>
    </table>
    <input type='hidden' name='action' value='actions_<?php echo $actions_type; ?>'>
    <?php
}





function snmptt_raise_message3($args) {
	
	if (count($args) > 0){
		if (!isset($args["mes_id"])) {
			if (isset($_SESSION["snmptt_output_messages"])) {
		        $mes_id = count($_SESSION["snmptt_output_messages"]) + 1;
		    }else{
			$mes_id = 1;
			}	
		}else{
			$mes_id = $args["mes_id"];
		}
		foreach($args as $arg => $value) {
			$_SESSION["snmptt_output_messages"][$mes_id][$arg] = $value;
		}
	}
return $mes_id;
}

function snmptt_covert_rezult_2_color ($str_rezult) {
$rezult="";

if ( $str_rezult == "OK" ) {
	$rezult="00BF47";
} elseif ($str_rezult == "OK") {
	$rezult="";
} else {
	$rezult="ff7d00";
}
return $rezult;
};


function snmptt_display_output_messages() {
global $config, $colors;
	if (isset($_SESSION["snmptt_output_messages"])) {
		//$error_message = is_error_message();
		$i = 0;
		if (is_array($_SESSION["snmptt_output_messages"])) {
        html_start_box("<strong>Rezults</strong>", "98%", "009F67" , "5", "center", ""); 
			    $nav = "<tr bgcolor='#" . "009F67" . "'>
					<td colspan='5'>
	                <table width='100%' cellspacing='0' cellpadding='0' border='0'>
	                    
	                </table>
					</td>
					</tr>\n";
			print $nav;
			html_header(array("Device","","Operation",   "Rezult", "Check"));
			
			foreach ($_SESSION["snmptt_output_messages"] as $current_message) {
				//eval ('$message = "' . $current_message["message"] . '";');
				form_alternate_row_color($colors["alternate"],$colors["light"],$i); $i++;
					?>
					<td><?php print $current_message["device_descr"];?></td>
					<?php 
					if ($current_message["type"] != 'title') {
						if ($current_message["cellpading"] == "true")  {
							print "<td width=2%></td>";
							?><td COLSPAN="1"><?php print $current_message["message"];?></td><?php
						}else {
							?><td COLSPAN="2"><?php print $current_message["message"];?></td><?php
						}
					}

				switch ($current_message["type"]) {
					case 'title' :
						?>
							<td COLSPAN="4"><?php print $current_message["message"];?></td>
						<?php	
						break;
					case 'title_count' :
						?>
							<td COLSPAN="2" ALIGN="CENTER" BGCOLOR="#<?php print snmptt_covert_rezult_2_color($current_message["count_rez"]) ?>"><?php print "Done " . ((isset($current_message["count_done"]) ) ? $current_message["count_done"] : "-") . " of " . ((isset($current_message["count_all"]) ) ? $current_message["count_all"] : "-");?></td>
						<?php	
						break;
					case 'update_db':
						?>
							<td ALIGN="CENTER" BGCOLOR="#<?php print snmptt_covert_rezult_2_color($current_message["step_rezult"] ) ?>"><?php print $current_message["step_rezult"] ;?></td>
							<td ALIGN="CENTER" BGCOLOR="#<?php print snmptt_covert_rezult_2_color($current_message["step_rezult"]) ?>"><?php print $current_message["step_data"];?></td>
						<?php					
						break;						
				}		
			}
		print "</table><br>";
		html_end_box(false);
		print "<br>";
		}
	}
kill_session_var("snmptt_output_messages");
}




function snmptt_delete_traps($row_ids){
	db_execute("DELETE FROM `plugin_snmptt` where `id` in ("  . $row_ids . ");");
	
}

function snmptt_delete_unk_traps($row_ids){
	db_execute("DELETE FROM `plugin_snmptt_unknown` where `id` in ("  . $row_ids . ");");
	
}

function snmptt_delete_alerts($row_ids){
	db_execute("DELETE FROM `plugin_snmptt_alert` where `id` in ("  . $row_ids . ");");
	
}
function snmptt_change_alert($a_id, $a_name, $a_hostname, $a_eventname, $a_type, $a_mode, $a_message, $a_email, $a_user, $a_date){
	$sql_str="UPDATE `plugin_snmptt_alert` SET " .
	" `name`='" . $a_name . "', " .
	" `hostname`='" . $a_hostname . "', " .
	" `eventname`='" . $a_eventname . "', " .
	" `type`='" . $a_type . "', " .
	" `mode`='" . $a_mode . "', " .
	" `message`='" . $a_message . "', " .
	" `email`='" . $a_email . "', " .
	" `user`='" . $a_user . "', " .
	" `date`='" . $a_date . "' " .
	"where `id`='"  . $a_id . "';";
	return db_execute($sql_str);
	
}
function snmptt_add_alert( $a_name, $a_hostname, $a_eventname, $a_type, $a_message, $a_mode, $a_email, $a_user, $a_date){
	db_execute("INSERT INTO `plugin_snmptt_alert` (`name`,`hostname`,`eventname`,`type`,`mode`,`message`,`email`,`user`,`date`) VALUES (" .
	" '" . $a_name . "', " .
	" '" . $a_hostname . "', " .
	" '" . $a_eventname . "', " .
	" '" . $a_type . "', " .
	" '" . $a_mode . "', " .
	" '" . $a_message . "', " .
	" '" . $a_email . "', " .
	" '" . $a_user . "', " .
	" '" . $a_date . "');");
	
}
function snmptt_grow_dhtml_trees() {
	global $colors, $config;

	//include_once($config["library_path"] . "/tree.php");
	//include_once($config["library_path"] . "/data_query.php");

	?>
	<script type="text/javascript">
	<!--
	USETEXTLINKS = 1
	STARTALLOPEN = 0
	USEFRAMES = 0
	USEICONS = 0
	WRAPTEXT = 1
	PERSERVESTATE = 1
	HIGHLIGHT = 1
	<?php
	/* get current time */
	list($micro,$seconds) = split(" ", microtime());
	$current_time = $seconds + $micro;
	$expand_hosts = read_graph_config_option("expand_hosts");


		
	if (!isset($_SESSION['snmptt_dhtml_tree'])) {
		$dhtml_tree = snmptt_create_dhtml_tree_my();
		$_SESSION['snmptt_dhtml_tree'] = $dhtml_tree;
	}else{
		$dhtml_tree = $_SESSION['snmptt_dhtml_tree'];
		if (($dhtml_tree[0] + read_config_option("snmptt_tree_update") < $current_time) || ($expand_hosts != $dhtml_tree[1])) {
			$dhtml_tree = snmptt_create_dhtml_tree_my();
			$_SESSION['snmptt_dhtml_tree'] = $dhtml_tree;
		}else{
			$dhtml_tree = $_SESSION['snmptt_dhtml_tree'];
		}
	}

	$total_tree_items = sizeof($dhtml_tree) - 1;

	for ($i = 2; $i <= $total_tree_items; $i++) {
		print $dhtml_tree[$i];
	}
	?>
	foldersTree.treeID = "t2";
	//-->
	</script>
	<?php
}
function snmptt_recreate_tree_db(){
	list($micro,$seconds) = split(" ", microtime());
	$start = $seconds + $micro;
	
	db_execute("TRUNCATE table `plugin_snmptt_tree`;");
	db_execute("INSERT INTO `plugin_snmptt_tree` (`device_type_name`,`host_template_id`,`description`,`hostname`,`eventname`,`agentip`)
		SELECT distinct `host_template`.`name`,`host_template`.`id`, `host`.`description`, `plugin_snmptt`.`hostname`, `eventname`, INET_ATON(`agentip`) as key_host FROM `plugin_snmptt`
		left join `host` on (`plugin_snmptt`.`hostname`=`host`.`hostname`)
		left join `host_template` on (`host`.`host_template_id`=`host_template`.`id`)");
	db_execute("REPLACE INTO settings (name, value) VALUES ('snmptt_last_treedb_time', '" . strtotime("now") . "')");

	list($micro,$seconds) = split(" ", microtime());
	$end = $seconds + $micro;
	$snmptt_stats_tree = sprintf(
	"TreeTime:%01.4f " ,
	round($end-$start,4));
/* log to the database */
	db_execute("REPLACE INTO settings (name,value) VALUES ('stats_snmptt_tree', '" . $snmptt_stats_tree . "')");
		
}


function snmptt_create_dhtml_tree_my() {
	list($micro,$seconds) = split(" ", microtime());
	$start = $seconds + $micro;
	$dhtml_tree = array();
	
	snmptt_recreate_tree_db;

	$dhtml_tree[0] = $start;
	$dhtml_tree[1] = read_graph_config_option("expand_hosts");
	$dhtml_tree[2] = "foldersTree = gFld(\"\", \"\")\n";
	$dhtml_tree[3] = "ou0 = insFld(foldersTree, gFld(\"ALL Traps\", \"snmptt_view.php?snmptt_traps_device_type_id=&amp;snmptt_traps_device_id=-1&amp;snmptt_traps_eventname=&amp;snmptt_traps_category=-1&amp;snmptt_traps_severity=&amp;snmptt_filter_type_id=1&amp;snmptt_traps_filter=&amp;x=12&amp;y=9&amp;page=1&amp;\"))\n";
	$i = 3;
	$tier=1;
	$j = 0;
$tree_lists = db_fetch_assoc("SELECT * from `plugin_snmptt_tree` order by `device_type_name`, `agentip`;");
	if (sizeof($tree_lists) > 0) {
		foreach ($tree_lists as $tree_list) {
			$i++;
			$tree_list = $tree_lists[$j];
			$temp = '';
			if (isset($tree_list["description"])) {
				$name_leaf = "\"<strong>Host:<\/strong> " . addslashes($tree_list["description"]) . "\"";
			}else{
				$name_leaf = "\"<strong>IP:<\/strong> " . addslashes($tree_list["hostname"]) . "\"";
			}
			
			if (isset($tree_list["device_type_name"])) {
				//use old device_type_name leaf
				if ((isset($tree_lists[$j-1]["device_type_name"])) && ($tree_lists[$j-1]["device_type_name"]==$tree_list["device_type_name"])) { 
					if ($tree_lists[$j-1]["hostname"]==$tree_list["hostname"]) { 
						$dhtml_tree[$i] = "ou3 = insFld(ou2, gFld(\"<strong>Event:<\/strong> " . addslashes($tree_list["eventname"]) . "\", \"snmptt_view.php?snmptt_traps_device_type_id=&amp;snmptt_traps_device_id=" . $tree_list["id"] . "&amp;snmptt_traps_eventname=" . $tree_list["eventname"] . "&amp;snmptt_traps_category=-1&amp;snmptt_traps_severity=&amp;snmptt_filter_type_id=1&amp;snmptt_traps_filter=&amp;x=12&amp;y=9&amp;page=1&amp;\"))\n";										
					}else{
						$dhtml_tree[$i] = "ou2 = insFld(ou1, gFld(" . $name_leaf . ", \"snmptt_view.php?snmptt_traps_device_type_id=&amp;snmptt_traps_device_id=" . $tree_list["id"] . "&amp;snmptt_traps_eventname=&amp;snmptt_traps_category=-1&amp;snmptt_traps_severity=&amp;snmptt_filter_type_id=1&amp;snmptt_traps_filter=&amp;x=12&amp;y=9&page=1&amp;\"))\n";
						$i++;  
						$dhtml_tree[$i] = "ou3 = insFld(ou2, gFld(\"<strong>Event:<\/strong> " . addslashes($tree_list["eventname"]) . "\", \"snmptt_view.php?snmptt_traps_device_type_id=&amp;snmptt_traps_device_id=" . $tree_list["id"] . "&amp;snmptt_traps_eventname=" . $tree_list["eventname"] . "&amp;snmptt_traps_category=-1&amp;snmptt_traps_severity=&amp;snmptt_filter_type_id=1&amp;snmptt_traps_filter=&amp;x=12&amp;y=9&page=1&amp;\"))\n";					
					}
					
				}else{
					//create new device_type_name leaf
					$dhtml_tree[$i] = "ou1 = insFld(ou0, gFld(\"<strong>Type:<\/strong> " . addslashes($tree_list["device_type_name"]) . "\", \"snmptt_view.php?snmptt_traps_device_type_id=" . $tree_list["host_template_id"] . "&amp;snmptt_traps_device_id=&amp;snmptt_traps_eventname=&amp;snmptt_traps_category=-1&amp;snmptt_traps_severity=&amp;snmptt_filter_type_id=1&amp;snmptt_traps_filter=&amp;x=12&amp;y=9&amp;page=1&amp;\"))\n";
					$i++;  
                    $dhtml_tree[$i] = "ou2 = insFld(ou1, gFld(" . $name_leaf . ", \"snmptt_view.php?snmptt_traps_device_type_id=&amp;snmptt_traps_device_id=" . $tree_list["id"] . "&amp;snmptt_traps_eventname=&amp;snmptt_traps_category=-1&amp;snmptt_traps_severity=&amp;snmptt_filter_type_id=1&amp;snmptt_traps_filter=&amp;x=12&amp;y=9&page=1&amp;\"))\n";
					$i++;  
                    $dhtml_tree[$i] = "ou3 = insFld(ou2, gFld(\"<strong>Event:<\/strong> " . addslashes($tree_list["eventname"]) . "\", \"snmptt_view.php?snmptt_traps_device_type_id=&amp;snmptt_traps_device_id=" . $tree_list["id"] . "&amp;snmptt_traps_eventname=" . $tree_list["eventname"] . "&amp;snmptt_traps_category=-1&amp;snmptt_traps_severity=&amp;snmptt_filter_type_id=1&amp;snmptt_traps_filter=&amp;x=12&amp;y=9&amp;page=1&amp;\"))\n";					
				}
				
			}else {
				if ((isset($tree_lists[$j-1]["hostname"])) && ($tree_lists[$j-1]["hostname"]==$tree_list["hostname"])) { 
					$dhtml_tree[$i] = "ou2 = insFld(ou1, gFld(\"<strong>Event:<\/strong> " . addslashes($tree_list["eventname"]) . "\", \"snmptt_view.php?snmptt_traps_device_type_id=&amp;snmptt_traps_device_id=" . $tree_list["id"] . "&amp;snmptt_traps_eventname=" . $tree_list["eventname"] . "&amp;snmptt_traps_category=-1&amp;snmptt_traps_severity=&amp;snmptt_filter_type_id=1&amp;snmptt_traps_filter=&amp;x=12&amp;y=9&amp;page=1&amp;\"))\n";										
				}else{
					$dhtml_tree[$i] = "ou1 = insFld(ou0, gFld(" . $name_leaf . ", \"snmptt_view.php?snmptt_traps_device_type_id=&amp;snmptt_traps_device_id=" . $tree_list["id"] . "&amp;snmptt_traps_eventname=&amp;snmptt_traps_category=-1&amp;snmptt_traps_severity=&amp;snmptt_filter_type_id=1&amp;snmptt_traps_filter=&amp;x=12&amp;y=9&amp;page=1&amp;\"))\n";
					$i++;  
					$dhtml_tree[$i] = "ou2 = insFld(ou1, gFld(\"<strong>Event:<\/strong> " . addslashes($tree_list["eventname"]) . "\", \"snmptt_view.php?snmptt_traps_device_type_id=&amp;snmptt_traps_device_id=" . $tree_list["id"] . "&amp;snmptt_traps_eventname="  . $tree_list["eventname"] . "&amp;snmptt_traps_category=-1&amp;snmptt_traps_severity=&amp;snmptt_filter_type_id=1&amp;snmptt_traps_filter=&amp;x=12&amp;y=9&amp;page=1\"))\n";					
				}				
			}
			$j++;
		}
	}

/* take time and log performance data */
list($micro,$seconds) = split(" ", microtime());
$end = $seconds + $micro;
$snmptt_stats_tree = sprintf(
	"TreeTime:%01.4f " ,
	round($end-$start,4));
/* log to the database */
db_execute("REPLACE INTO settings (name,value) VALUES ('stats_snmptt_tree', '" . $snmptt_stats_tree . "')");
	
return $dhtml_tree;
}

function snmptt_sendemail($to, $from, $subject, $message) {
	global $debug;
	if (snmptt_check_dependencies()) {
		if ($debug)
			print "      Sending Alert email to '" . $to . "'\n";
		send_mail($to, $from, $subject, $message);
	} else {
		if ($debug)
			print "      Could not send alert, you are missing the Settings plugin\n";
	}
}

function snmptt_check_regexp ($regexp) {
$RegEx = new RegEx;

 $rezult = array();
 $expression = preg_quote($regexp);
 $rezult["rezult"] = $RegEx->isValid("/" . $expression . "/");
 if (!$rezult["rezult"]) {
    $rezult["error"] = 'Your regular expression is invalid because: ' . $RegEx->error();
 }else{
	$rezult["regexp"] = $expression;
 }
 return $rezult;
}

function snmptt_create_where_sql ($alert) {

	$sql_where = '';

	if ($alert["hostname"] != "any" and $alert["hostname"] != "")  {
		if (strlen($sql_where) > 0) {
			$sql_where .= " AND ";
		}else{
			$sql_where = " WHERE ";
		}	
		$sql_where .= " (`hostname`='" . $alert["hostname"] . "') ";
	}			
	if ($alert["eventname"] != "any" and $alert["eventname"] != "")  {
		if (strlen($sql_where) > 0) {
			$sql_where .= " AND ";
		}else{
			$sql_where = " WHERE ";
		}	
		$sql_where .= " (`eventname`='" . $alert["eventname"] . "') ";
	}			


	if (strlen($sql_where) > 0) {
		$sql_where .= " AND ";
	}else{
		$sql_where = " WHERE ";
	}			
	if ($alert['type'] == 'Matches') {
		$sql_where .= "(`formatline`='" . $alert['message'] . "' )";
	} elseif ($alert['type'] == 'Contains') {
		$sql_where .= "(`formatline` like '%" . $alert['message'] . "%' )";
	} elseif ($alert['type'] == 'Begins With') {
		$sql_where .= "(`formatline` like '" . $alert['message'] . "%' )";
	} elseif ($alert['type'] == 'Ends With') {
		$sql_where .= "(`formatline` like '%" . $alert['message'] . "' )";
	} elseif ($alert['type'] == 'REGEXP') {
		$sql_where .= "(`formatline` REGEXP '" . preg_quote($alert['message']) . "' )";
	}


 return $sql_where;
}
// If current user have allow actions realms
function snmptt_check_config_access () {
global $user_auth_realm_filenames;
$rezult = false;

if (isset($user_auth_realm_filenames{"snmptt_alert.php"})) {
	$realm_id = $user_auth_realm_filenames{"snmptt_alert.php"};
	if ((db_fetch_assoc("select
		user_auth_realm.realm_id
		from
		user_auth_realm
		where user_auth_realm.user_id='" . $_SESSION["sess_user_id"] . "'
		and user_auth_realm.realm_id='$realm_id'")) && (!empty($realm_id))) {
			$rezult = true;
		}	
}


return $rezult;

}

function form_text_box_class($form_name, $form_previous_value, $form_default_value, $form_max_length, $form_size = 30, $type = "text", $current_id = 0, $class = "") {
	if (($form_previous_value == "") && (empty($current_id))) {
		$form_previous_value = $form_default_value;
	}

	print "<input type='$type'";

	if (strlen($class)) {
		$class = " class='$class' ";
	}

	if (isset($_SESSION["sess_error_fields"])) {
		if (!empty($_SESSION["sess_error_fields"][$form_name])) {
			print "class='txtErrorTextBox'";
			unset($_SESSION["sess_error_fields"][$form_name]);
		}
	}

	if (isset($_SESSION["sess_field_values"])) {
		if (!empty($_SESSION["sess_field_values"][$form_name])) {
			$form_previous_value = $_SESSION["sess_field_values"][$form_name];
		}
	}

	print " id='$form_name' name='$form_name' " . $class . " size='$form_size'" . (!empty($form_max_length) ? " maxlength='$form_max_length'" : "") . " value='" . htmlspecialchars($form_previous_value, ENT_QUOTES) . "'>\n";
}




?>
